# add modules folder to interpreter path
import sys
import os
modules_path = '../../../modules/'
if os.path.exists(modules_path):
    sys.path.insert(1, modules_path)

# init logging to file
import logging
LOG_FORMAT = ('%(levelname) -5s %(asctime)s %(name)s:%(funcName) -35s %(lineno) -5d:  %(message)s')
logging.basicConfig(level=logging.INFO, format=LOG_FORMAT)
LOGGER = logging.getLogger(__name__)

#################################
import connexion
from messaging.MessageReceiver import MessageReceiver
from messaging.MessageHandler import MessageHandler

# init message handler
message_rec: MessageReceiver = None
message_handler = MessageHandler()

def message_received_callback(channel, method, properties, body):
    message_handler.handle_generic(body)

def pika_error_callback(error):
    LOGGER.warning(f"RabbitMQ stopped with error: {error}")
    # restart receiver
    global message_rec
    message_rec.stop()
    init_message_receiver()

def init_message_receiver():
    global message_rec
    message_rec = MessageReceiver(exchange_name='datahub', exchange_type='direct', queue_name='semantic-linking', auto_ack=True)
    message_rec.start(message_received_callback, pika_error_callback)

# load swagger config
app = connexion.App(__name__, specification_dir='configs/')
app.add_api('swagger.yml')

@app.route('/', methods=['GET'])
def api_root():
    return 'Endpoint of semantic-linking-microservice!'

# start app
if __name__ == '__main__':
    init_message_receiver()
    app.run(host='0.0.0.0', port=5000, debug=True, use_reloader=False)
