import json
import requests
import network_constants as netconst
from db.MongoRepository import MongoRepository
from intelligence_zahra.Processor import Processor

import logging
LOGGER = logging.getLogger(__name__)

class MessageHandler:
    _processor: Processor = None

    def __init__(self):
        self._processor = Processor()

    def handle_generic(self, body):
        LOGGER.info(f"Received message: {body}")

        message = None
        try:
            message = json.loads(body)
        except ValueError:
            LOGGER.warning("Message is not in JSON format and is ignored")
            return

        if not 'type' in message:
            LOGGER.warning("Message has no type field and is ignored")
            return
        
        if message['type'] == 'new-traces-available':
            self.handle_new_traces_available()
        else:
            LOGGER.info("Message Type could not be processed")
            
    def handle_new_traces_available(self):
        # TODO remove workaround
        repo = MongoRepository()
        traces = list(repo.get_traces(projection={'_id':0}))
        self._processor.process(traces)
        repo.close_connection()

        return

        # get traces
        url = f'http://{netconst.TRACE_RETRIEVAL_HOSTNAME}:{netconst.TRACE_RETRIEVAL_REST_PORT}/api/trace'
        response = requests.get(url)
        if response.status_code == 200:
            traces = response.json()
            self._processor.process(traces)
        else:
            LOGGER.error(f"Could not retrieve JSON from {url} with GET request ({response.status_code})")
